@@ -1,6 +1,6 @@
 __author__ = """Aria Bagheri"""
 __email__ = 'ariab9342@gmail.com'
-__version__ = '1.0.1'
+__version__ = '1.0.2'
 
 import math
 import os
@@ -12,9 +12,8 @@ from typing import Callable
 import requests
 
 _HEADERS = {
-    'user-agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/1.0.1.94 Safari/537.36'
+    'user-agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/1.0.2.94 Safari/537.36'
 }
-_BLOCK_SIZE = 1024
 
 
 class _Progress:
@@ -28,41 +27,42 @@ class _Progress:
 
 
 class Axel:
-    def __init__(self):
-        pass
+    block_size = 5368709 * 2
+    connections: int = 64
+    progress_callback: Callable[[int, int], None] = None
 
-    def download_file(self, download_link: str, output: str, connections: int = 64,
-                      progress_callback: Callable[[int, int], None] = None):
+    def __init__(self, block_size: int = 5368709 * 2, connections: 64 = 64, progress_callback: Callable[[int, int], None] = None):
+        self.block_size = block_size
+        self.connections = connections
+        self.progress_callback = progress_callback
+
+    def download_file(self, link: str, output: str):
         output_path = pathlib.Path(output)
         if output_path.is_dir():
             raise Exception("Output is not a file!")
         os.makedirs("temp/", exist_ok=True)
 
-        download_head = requests.head(download_link)
+        download_head = requests.head(link)
         accept_ranges = 'accept-ranges' in download_head.headers and 'bytes' in download_head.headers['accept-ranges']
 
-        total_size = int(requests.head(download_link).headers['content-length'])
+        total_size = int(requests.head(link).headers['content-length'])
 
         if not accept_ranges:
-            self._download_file_slow(download_link, output, total_size, progress_callback)
+            self._download_file_slow(link, output, total_size)
         else:
-            self._download_file_multithread(download_link, output_path, total_size, connections, progress_callback)
+            self._download_file_multithread(link, output_path, total_size)
 
-    @staticmethod
-    def _download_file_slow(download_link: str, output: str, total_size: int,
-                            progress_callback: Callable[[int, int], None] = None):
+    def _download_file_slow(self, link: str, output: str, total_size: int):
         progress = _Progress()
-        with requests.get(download_link, allow_redirects=True, stream=True) as r:
+        with requests.get(link, allow_redirects=True, stream=True) as r:
             with open(output, 'wb') as f:
-                for chunk in r.iter_content(chunk_size=_BLOCK_SIZE):
+                for chunk in r.iter_content(chunk_size=self.block_size):
                     f.write(chunk)
                     progress.update(len(chunk))
-                    progress_callback(progress.value, total_size)
+                    self.progress_callback(progress.value, total_size)
 
-    @staticmethod
-    def _download_file_multithread(download_link: str, output: pathlib.Path, total_size: int, total_connections: int,
-                                   progress_callback: Callable[[int, int], None] = None):
-        chunk_size = math.ceil(total_size / total_connections)
+    def _download_file_multithread(self, link: str, output: pathlib.Path, total_size: int):
+        chunk_size = math.ceil(total_size / self.connections)
         progress = _Progress()
 
         def download_chunk(chunk_index):
@@ -79,23 +79,23 @@ class Axel:
             range_header['Range'] = f"bytes={start_chunk}-{end_chunk - 1}"
 
             try:
-                with requests.get(download_link, headers=range_header, timeout=30,
+                with requests.get(link, headers=range_header, timeout=30,
                                   allow_redirects=True, stream=True) as r:
                     with open(chunk_path, 'wb') as f:
-                        for chunk in r.iter_content(chunk_size=_BLOCK_SIZE):
+                        for chunk in r.iter_content(chunk_size=self.block_size):
                             f.write(chunk)
                             progress.update(len(chunk))
-                            progress_callback(progress.value, total_size)
+                            self.progress_callback(progress.value, total_size)
 
             except requests.exceptions.RequestException as e:
                 print(e)
 
         with ThreadPool() as pool:
-            pool.map(download_chunk, range(total_connections))
+            pool.map(download_chunk, range(self.connections))
 
         with open(output, 'wb') as fm:
-            for i in range(total_connections):
+            for i in range(self.connections):
                 temp_path = f"temp/{output.stem}.{i}.tmp"
                 with open(temp_path, 'rb') as fi:
-                    shutil.copyfileobj(fi, fm, _BLOCK_SIZE)
+                    shutil.copyfileobj(fi, fm, self.block_size)
                 os.remove(temp_path)
